@@ -2,8 +2,8 @@ package operator
 
 import (
 	// standard lib
+	"context"
 	"fmt"
-	"reflect"
 	"time"
 
 	// kube
@@ -22,11 +22,11 @@ import (
 	oauthinformersv1 "github.com/openshift/client-go/oauth/informers/externalversions/oauth/v1"
 	routeclientv1 "github.com/openshift/client-go/route/clientset/versioned/typed/route/v1"
 	"github.com/openshift/console-operator/pkg/api"
-
 	"github.com/openshift/library-go/pkg/operator/events"
 	"github.com/openshift/library-go/pkg/operator/resource/resourceapply"
 	"github.com/openshift/library-go/pkg/operator/resourcesynccontroller"
 	"github.com/openshift/library-go/pkg/operator/status"
+	"github.com/openshift/library-go/pkg/operator/v1helpers"
 
 	"monis.app/go/openshift/operator"
 
@@ -42,11 +42,9 @@ import (
 	operatorclientv1 "github.com/openshift/client-go/operator/clientset/versioned/typed/operator/v1"
 
 	// operator
-	statushelpers "github.com/openshift/console-operator/pkg/console/status"
 	"github.com/openshift/console-operator/pkg/console/subresource/configmap"
 	"github.com/openshift/console-operator/pkg/console/subresource/deployment"
 	"github.com/openshift/console-operator/pkg/console/subresource/oauthclient"
-	"github.com/openshift/console-operator/pkg/console/subresource/route"
 	"github.com/openshift/console-operator/pkg/console/subresource/secret"
 )
 
@@ -56,6 +54,7 @@ const (
 
 type consoleOperator struct {
 	// configs
+	operatorClient             v1helpers.OperatorClient
 	operatorConfigClient       operatorclientv1.ConsoleInterface
 	consoleConfigClient        configclientv1.ConsoleInterface
 	infrastructureConfigClient configclientv1.InfrastructureInterface
@@ -72,6 +71,8 @@ type consoleOperator struct {
 	// recorder
 	recorder       events.Recorder
 	resourceSyncer resourcesynccontroller.ResourceSyncer
+	// context
+	ctx context.Context
 }
 
 func NewConsoleOperator(
@@ -79,6 +80,7 @@ func NewConsoleOperator(
 	configClient configclientv1.ConfigV1Interface,
 	configInformer configinformer.SharedInformerFactory,
 	// operator
+	operatorClient v1helpers.OperatorClient,
 	operatorConfigClient operatorclientv1.OperatorV1Interface,
 	operatorConfigInformer operatorinformerv1.ConsoleInformer,
 	// core resources
@@ -99,9 +101,12 @@ func NewConsoleOperator(
 	versionGetter status.VersionGetter,
 	recorder events.Recorder,
 	resourceSyncer resourcesynccontroller.ResourceSyncer,
+	// context
+	ctx context.Context,
 ) operator.Runner {
 	c := &consoleOperator{
 		// configs
+		operatorClient:             operatorClient,
 		operatorConfigClient:       operatorConfigClient.Consoles(),
 		consoleConfigClient:        configClient.Consoles(),
 		infrastructureConfigClient: configClient.Infrastructures(),
@@ -119,6 +124,7 @@ func NewConsoleOperator(
 		// recorder
 		recorder:       recorder,
 		resourceSyncer: resourceSyncer,
+		ctx:            ctx,
 	}
 
 	secretsInformer := coreV1.Secrets()
@@ -150,7 +156,7 @@ func NewConsoleOperator(
 
 // key is actually the pivot point for the operator, which is our Console custom resource
 func (c *consoleOperator) Key() (metav1.Object, error) {
-	return c.operatorConfigClient.Get(api.ConfigResourceName, metav1.GetOptions{})
+	return c.operatorConfigClient.Get(c.ctx, api.ConfigResourceName, metav1.GetOptions{})
 }
 
 type configSet struct {
@@ -169,20 +175,20 @@ func (c *consoleOperator) Sync(obj metav1.Object) error {
 	operatorConfig := obj.(*operatorsv1.Console)
 
 	// ensure we have top level console config
-	consoleConfig, err := c.consoleConfigClient.Get(api.ConfigResourceName, metav1.GetOptions{})
+	consoleConfig, err := c.consoleConfigClient.Get(c.ctx, api.ConfigResourceName, metav1.GetOptions{})
 	if err != nil {
 		klog.Errorf("console config error: %v", err)
 		return err
 	}
 
 	// we need infrastructure config for apiServerURL
-	infrastructureConfig, err := c.infrastructureConfigClient.Get(api.ConfigResourceName, metav1.GetOptions{})
+	infrastructureConfig, err := c.infrastructureConfigClient.Get(c.ctx, api.ConfigResourceName, metav1.GetOptions{})
 	if err != nil {
 		klog.Errorf("infrastructure config error: %v", err)
 		return err
 	}
 
-	proxyConfig, err := c.proxyConfigClient.Get(api.ConfigResourceName, metav1.GetOptions{})
+	proxyConfig, err := c.proxyConfigClient.Get(c.ctx, api.ConfigResourceName, metav1.GetOptions{})
 	if err != nil {
 		klog.Errorf("proxy config error: %v", err)
 		return err
@@ -211,31 +217,15 @@ func (c *consoleOperator) handleSync(configs configSet) error {
 		// handled below
 	case operatorsv1.Unmanaged:
 		klog.V(4).Infoln("console is in an unmanaged state.")
-		if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-			statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
-		}
 		return nil
 	case operatorsv1.Removed:
 		klog.V(4).Infoln("console has been removed.")
-		if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-			statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
-		}
 		return c.removeConsole()
 	default:
-		if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-			statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
-		}
 		return fmt.Errorf("console is in an unknown state: %v", updatedStatus.Spec.ManagementState)
 	}
 
-	err := c.sync_v400(updatedStatus, configs)
-
-	// finally write out the set of conditions currently set if anything has changed
-	// to avoid a hot loop
-	if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-		statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
-	}
-	return err
+	return c.sync_v400(updatedStatus, configs)
 }
 
 // this may need to move to sync_v400 if versions ever have custom delete logic
@@ -243,23 +233,21 @@ func (c *consoleOperator) removeConsole() error {
 	klog.V(2).Info("deleting console resources")
 	defer klog.V(2).Info("finished deleting console resources")
 	var errs []error
-	// route
-	errs = append(errs, c.routeClient.Routes(api.TargetNamespace).Delete(route.Stub().Name, &metav1.DeleteOptions{}))
 	// configmaps
-	errs = append(errs, c.configMapClient.ConfigMaps(api.TargetNamespace).Delete(configmap.Stub().Name, &metav1.DeleteOptions{}))
-	errs = append(errs, c.configMapClient.ConfigMaps(api.TargetNamespace).Delete(configmap.ServiceCAStub().Name, &metav1.DeleteOptions{}))
+	errs = append(errs, c.configMapClient.ConfigMaps(api.TargetNamespace).Delete(c.ctx, configmap.Stub().Name, metav1.DeleteOptions{}))
+	errs = append(errs, c.configMapClient.ConfigMaps(api.TargetNamespace).Delete(c.ctx, configmap.ServiceCAStub().Name, metav1.DeleteOptions{}))
 	// secret
-	errs = append(errs, c.secretsClient.Secrets(api.TargetNamespace).Delete(secret.Stub().Name, &metav1.DeleteOptions{}))
+	errs = append(errs, c.secretsClient.Secrets(api.TargetNamespace).Delete(c.ctx, secret.Stub().Name, metav1.DeleteOptions{}))
 	// existingOAuthClient is not a delete, it is a deregister/neutralize
-	existingOAuthClient, getAuthErr := c.oauthClient.OAuthClients().Get(oauthclient.Stub().Name, metav1.GetOptions{})
+	existingOAuthClient, getAuthErr := c.oauthClient.OAuthClients().Get(c.ctx, oauthclient.Stub().Name, metav1.GetOptions{})
 	errs = append(errs, getAuthErr)
 	if len(existingOAuthClient.RedirectURIs) != 0 {
-		_, updateAuthErr := c.oauthClient.OAuthClients().Update(oauthclient.DeRegisterConsoleFromOAuthClient(existingOAuthClient))
+		_, updateAuthErr := c.oauthClient.OAuthClients().Update(c.ctx, oauthclient.DeRegisterConsoleFromOAuthClient(existingOAuthClient), metav1.UpdateOptions{})
 		errs = append(errs, updateAuthErr)
 	}
 	// deployment
 	// NOTE: CVO controls the deployment for downloads, console-operator cannot delete it.
-	errs = append(errs, c.deploymentClient.Deployments(api.TargetNamespace).Delete(deployment.Stub().Name, &metav1.DeleteOptions{}))
+	errs = append(errs, c.deploymentClient.Deployments(api.TargetNamespace).Delete(c.ctx, deployment.Stub().Name, metav1.DeleteOptions{}))
 	// clear the console URL from the public config map in openshift-config-managed
 	_, _, updateConfigErr := resourceapply.ApplyConfigMap(c.configMapClient, c.recorder, configmap.EmptyPublicConfig())
 	errs = append(errs, updateConfigErr)
